Module platform

Module platform 

The platform layer allows the host program to discover OpenCL devices and their capabilities and to create contexts.

Functions

get_platform_ids
Returns the list of all platforms available
get_platform_info